.. _citeus:
:html_theme.sidebar_secondary.remove: true
:html_theme.sidebar_primary.remove: true

********
Cite Us!
********

If you use MCEq in your scientific publication, please cite the code **AND** the physical models.

The current citation for the MCEq is:

   | *Calculation of conventional and prompt lepton fluxes at very high energy*
   | A. Fedynitch, R. Engel, T. K. Gaisser, F. Riehn, T. Stanev,
   | EPJ Web Conf. 99 (2015) 08001
   | `arXiv:1503.00544 <http://arxiv.org/abs/1503.00544>`_

The citation for specific lepton flux calcations can be found here:

   | *Hadronic interaction model sibyll 2.3c and inclusive lepton fluxes*
   | A. Fedynitch, F. Riehn, R. Engel, T. K. Gaisser, T. Stanev
   | Phys.Rev.D 100 (2019) 10, 103018
   | `arXiv:1806.04140 <http://arxiv.org/abs/1806.04140>`_



************
Cite Others!
************

Cosmic-ray flux parameterizations
=================================

The parameterizations of the flux of cosmic rays are provided via the module `crflux <https://github.com/afedynitch/crflux>`_.
The references are given in the `module's documentation <http://crfluxmodels.readthedocs.org/en/latest/index.html#>`_.

Atmosphere
==========

* `CORSIKA parametrizations <https://web.ikp.kit.edu/corsika/physics_description/corsika_phys.pdf>`_
    | *CORSIKA: A Monte Carlo Code to Simulate Extensive Air Showers*
    | D. Heck, J. Knapp, J. Capdevielle, G. Schatz, T. Thouw
    | Tech. Rep. FZKA 6019, Karsruhe (1998)

* `NRLMSISE-00 <http://ccmc.gsfc.nasa.gov/modelweb/atmos/nrlmsise00.html>`_
    | *NRLMSISE-00 empirical model of the atmosphere: Statistical comparisons and scientific issues*
    | J.M. Picone, A.E. Hedin, D.P. Drob, and A.C. Aikin
    | J. Geophys. Res., 107(A12), 1468, doi:10.1029/2002JA009430, (2002)

Hadronic interaction models
===========================

* `SIBYLL★ <https://inspirehep.net/literature/2774307>`_:
    | *Sibyll★*
    | F. Riehn,  A. Fedynitch, R. Engel
    | Astropart.Phys. 160 (2024) 102964
    | `arXiv:2404.02636 <https://arxiv.org/pdf/2404.02636>`_
    
* `SIBYLL-2.3d & c <https://inspirehep.net/literature/1768983>`_:
    | *Hadronic interaction model sibyll 2.3d and extensive air showers*
    | F. Riehn, R. Engel, A. Fedynitch, T. K. Gaisser, T. Stanev
    | Phys.Rev.D 102 (2020) 6, 063002
    | `arXiv:1912.03300 <http://arxiv.org/abs/1912.03300>`_
    
* `SIBYLL-2.3c <https://inspirehep.net/literature/1677505>`_:
    | *Hadronic interaction model sibyll 2.3c and inclusive lepton fluxes*
    | A. Fedynitch, F. Riehn, R. Engel, T. K. Gaisser, T. Stanev
    | Phys.Rev.D 100 (2019) 10, 103018
    | `arXiv:1806.04140 <http://arxiv.org/abs/1806.04140>`_

* `SIBYLL-2.3 <http://inspirehep.net/record/1395980>`_:
    | *A new version of the event generator Sibyll*
    | F. Riehn, R. Engel, A. Fedynitch, T. K. Gaisser, T. Stanev
    | PoS ICRC2015 (2016) 558

* `SIBYLL-2.1 <http://inspirehep.net/record/823839>`_:
    | *Cosmic ray interaction event generator SIBYLL 2.1*
    | E.-J. Ahn, R. Engel, T. K. Gaisser, P. Lipari, T.Stanev
    | Phys.Rev. D80 (2009) 094003

* `EPOS-LHC-R <https://inspirehep.net/literature/2959029>`_:
    | *EPOS LHC-R : a global approach to solve the muon puzzle*
    | T. Pierog and K. Werner
    | PoS ICRC2025 (2025) 358
    | `PoS <https://pos.sissa.it/501/358/pdf>`_

* `EPOS-LHC <http://inspirehep.net/record/1236629>`_:
    | *EPOS LHC : test of collective hadronization with LHC data*
    | T. Pierog, I. Karpenko, J. M. Katzy, E. Yatsenko, and K. Werner
    | Phys. Rev. C92 (2015) 034906
    | `arXiv:1306.0121 <https://arxiv.org/abs/1306.0121>`_

* `QGSJET-III Particle Production and Extensive Air Showers <https://inspirehep.net/literature/2771416>`_:
    | *QGSJET-III model of high energy hadronic interactions: II. Particle production and extensive air shower characteristics*
    | Sergey Ostapchenko
    | Phys.Rev.D 109 (2024) 9, 094019,

* `QGSJET-III Formalism <https://inspirehep.net/literature/2746395>`_:
    | *QGSJET-III model of high energy hadronic interactions: The formalism*
    | Sergey Ostapchenko
    | Phys.Rev.D 109 (2024) 3, 034002,

* `QGSJET-II-04 <http://inspirehep.net/record/872658>`_:
    | *Monte Carlo treatment of hadronic interactions in enhanced Pomeron scheme: I. QGSJET-II model*
    | Sergey Ostapchenko
    | Phys.Rev. D83 (2011) 014018,

* `DPMJET-III <http://inspirehep.net/record/538940>`_:
    | *The Monte Carlo event generator DPMJET-III*
    | S. Roesler, R. Engel, J. Ranft
    | Advanced Monte Carlo for radiation physics, particle transport simulation and applications. Proceedings, Conference, MC2000, Lisbon, Portugal, October 23-26, 2000

* `DPMJET-III-19.1 <http://inspirehep.net/record/1503512>`_:
    | *Cascade equations and hadronic interactions at very high energies*
    | A. Fedynitch
    | CERN-THESIS-2015-371
